@@ -161,14 +161,14 @@ public:
 
 private:
 
-    void dragEnterEvent(QDragEnterEvent* e) Q_DECL_OVERRIDE;
-    void dragMoveEvent(QDragMoveEvent* e) Q_DECL_OVERRIDE;
-    void dropEvent(QDropEvent* e) Q_DECL_OVERRIDE;
-    void contextMenuEvent(QContextMenuEvent * e) Q_DECL_OVERRIDE;
+    void dragEnterEvent(QDragEnterEvent* e) override;
+    void dragMoveEvent(QDragMoveEvent* e) override;
+    void dropEvent(QDropEvent* e) override;
+    void contextMenuEvent(QContextMenuEvent * e) override;
 
     void setup(int iconSize);
 
-    void drawRow(QPainter* p, const QStyleOptionViewItem& opt, const QModelIndex& index) const Q_DECL_OVERRIDE;
+    void drawRow(QPainter* p, const QStyleOptionViewItem& opt, const QModelIndex& index) const override;
 
 private:
 
