@@ -49,7 +49,7 @@ public:
     Plugin_Rajce(QObject* const parent, const QVariantList& args);
     ~Plugin_Rajce();
 
-    void setup(QWidget* const) Q_DECL_OVERRIDE;
+    void setup(QWidget* const) override;
 
 public Q_SLOTS:
 
